@@ -35,12 +35,13 @@
 #define CG_BUILD_SCOPE  0
 #define CG_BUILD_BASESCOPE 0
 #define CG_BUILD_PARALLEL  0
+#define CG_BUILD_COMPLEX_C99_EXT 0
 
 #define CG_MAX_INT32 0x7FFFFFFF
 #ifdef _WIN32
 # define CG_LONG_T __int64
 #ifdef _MSC_VER
-# ifdef CG_BUILD_64BIT
+# if CG_BUILD_64BIT
 #  define stat _stat32i64
 # endif
 #endif
